@@ -8,7 +8,7 @@ no if $] >= 5.018, warnings => "experimental::smartmatch";
 
 use parent 'Class::Accessor';
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 Travel::Status::DE::DeutscheBahn::Result->mk_ro_accessors(
 	qw(date time train route_end route_raw platform info_raw));
@@ -137,6 +137,15 @@ sub TO_JSON {
 	return { %{$self} };
 }
 
+sub type {
+	my ($self) = @_;
+
+	# $self->{train} is either "TYPE 12345" or "TYPE12345"
+	my ($type) = ( $self->{train} =~ m{ ^ ([A-Z]+) }x );
+
+	return $type;
+}
+
 1;
 
 __END__
@@ -171,7 +180,7 @@ arrival/departure received by Travel::Status::DE::DeutscheBahn
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 DESCRIPTION
 
@@ -259,6 +268,11 @@ references of the form C<< [ arrival time, station name ] >>.
 
 Returns the arrival/departure time as string in "hh:mm" format.
 
+=item $result->type
+
+Returns the type of this train, e.g. "S" for S-Bahn, "RE" for Regional Express
+or "ICE" for InterCity-Express.
+
 =back
 
 =head2 INTERNAL
